@@ -24,6 +24,7 @@ package org.kapott.hbci.dialog;
 import java.util.ArrayList;
 import java.util.List;
 
+import org.kapott.hbci.status.HBCIMsgStatus;
 import org.kapott.hbci.status.HBCIRetVal;
 
 /**
@@ -71,6 +72,11 @@ public enum KnownReturncode
      */
     E9942("9942"),
     
+    /**
+     *  Neue Kundensystem-ID holen
+     */
+    E9391("9391"),
+    
     ;
     
     /**
@@ -133,34 +139,16 @@ public enum KnownReturncode
     /**
      * Sucht nach dem angegebenen Status-Code in den Rueckmeldungen und liefert den Code zurueck.
      * @param rets die Rueckmeldungen.
-     * @return der gesuchte Rueckmeldecode oder NULL, wenn er nicht existiert.
-     * Es wird der erste gefundene verwendet.
-     */
-    public HBCIRetVal searchReturnValue(HBCIRetVal[] rets)
-    {
-        if (rets == null || rets.length == 0)
-            return null;
-        
-        for (HBCIRetVal ret:rets)
-        {
-            if (this.is(ret.code))
-                return ret;
-        }
-        return null;
-    }
-
-    /**
-     * Sucht nach dem angegebenen Status-Code in den Rueckmeldungen und liefert den Code zurueck.
-     * @param rets die Rueckmeldungen.
-     * @return die gesuchten Rueckmeldecodes oder NULL, wenn sie nicht existieren.
+     * @return die gesuchten Rueckmeldecodes oder eine leere Liste. Nie NULL.
      * Es werden alle gefundenen geliefert.
      */
     public List<HBCIRetVal> searchReturnValues(HBCIRetVal[] rets)
     {
+      List<HBCIRetVal> result = new ArrayList<HBCIRetVal>();
+      
         if (rets == null || rets.length == 0)
-            return null;
+            return result;
 
-        List<HBCIRetVal> result = new ArrayList<HBCIRetVal>();
         for (HBCIRetVal ret:rets)
         {
             if (this.is(ret.code))
@@ -168,4 +156,36 @@ public enum KnownReturncode
         }
         return result;
     }
+
+    /**
+     * Sucht im gesamten Nachrichten-Status nach dem Status-Code.
+     * @param status der Nachrichten-Status.
+     * @return die Rückmeldecodes.
+     */
+    public List<HBCIRetVal> searchReturnValues(HBCIMsgStatus status)
+    {
+      List<HBCIRetVal> result = new ArrayList<HBCIRetVal>();
+      if (status == null)
+        return result;
+      
+      if (status.globStatus != null)
+        result.addAll(this.searchReturnValues(status.globStatus.getRetVals()));
+      if (status.segStatus != null)
+        result.addAll(this.searchReturnValues(status.segStatus.getRetVals()));
+      
+      return result;
+    }
+
+    /**
+     * Sucht nach dem angegebenen Status-Code in den Rueckmeldungen und liefert den Code zurueck.
+     * @param rets die Rueckmeldungen.
+     * @return der gesuchte Rueckmeldecode oder NULL, wenn er nicht existiert.
+     * Es wird der erste gefundene verwendet.
+     */
+    public HBCIRetVal searchReturnValue(HBCIRetVal[] rets)
+    {
+      final List<HBCIRetVal> found = this.searchReturnValues(rets);
+      return !found.isEmpty() ? found.get(0) : null;
+    }
+
 }
