@@ -206,13 +206,15 @@ public class HBCIBatch {
                     int rounds = 0;
                     File tanFile = new File(value);
                     String tan = null;
-                    while (rounds < 60) {
+                    while (rounds < 120) {
                         if (tanFile.exists()) {
                             try {
                                 BufferedReader brTest = new BufferedReader(new FileReader(tanFile));
                                 tan = brTest.readLine();
                                 if (!tan.isEmpty()) {
                                     retData.replace(0, retData.length(), tan);
+                                    //lösche die verwendete TAN, da Folge GVs ggf. neue TANs erfordern
+                                    new FileWriter(tanFile, false).close();
                                     break;
                                 }
                                 brTest.close();
